from setuptools import setup

setup(
    name='ellinet13s-lib',
    version='2.0.0',
    author='ElliNet13',
    author_email='ellinet13@googlegroups.com',
    description='A library made by ElliNet13',
    long_description='This library was made by ElliNet13 and will stay like that.',
    long_description_content_type='text/markdown',
    url='https://github.com/ElliNet13/ellinet13s-lib',
    packages=['ellinet13s-lib'],
    classifiers=[
        
    ],
    install_requires=[
        'wheel'
    ],
)
